@@ -1,5 +1,5 @@
 package File::Touch;
-$File::Touch::VERSION = '0.10';
+$File::Touch::VERSION = '0.11';
 use 5.006;
 use warnings;
 use strict;
@@ -175,7 +175,9 @@ If nonzero, do not create new files. Default is zero.
 
 =item reference => $reference_file
 
-If defined, use timestamps from this file instead of current time. Default is undefined.
+If defined, use timestamps from this file instead of current time. The timestamps are read
+from the reference file when the object is created, not when C<<->touch>> is invoked.
+Default is undefined.
 
 =item time => $time
 
@@ -222,6 +224,13 @@ If defined, use this time (in epoch seconds) instead of current time for modific
  my $count = $ref->touch(@files);
  print "$count files updated\n";
 
+=head2 Make a change to a file, keeping its timestamps unchanged
+
+ use File::Touch;
+ my $date_restorer = File::Touch->new(reference => $file);
+ # Update the contents of $file here.
+ $date_restorer->touch($file);
+
 =head1 REPOSITORY
 
 L<https://github.com/neilb/File-Touch>
